@@ -2,7 +2,7 @@
 #!/bin/ksh
 #!/bin/zsh -y
 #===============================================================================
-# lesspipe.sh, a preprocessor for less (version 1.10)
+# lesspipe.sh, a preprocessor for less (version 1.21)
 #
 # Usage:   lesspipe.sh is called when the environment variable LESSOPEN is set:
 #	   LESSOPEN="|lesspipe.sh %s"; export LESSOPEN	(sh like shells)
@@ -26,6 +26,7 @@
 # Supported formats:
 #	   gzip, compress, bzip2, zip, tar, nroff(mandoc), ar library, pdf,
 #	   shared library, executable, directory, RPM, Microsoft Word, Debian
+#	   files and Filesystems on removable media via /dev/xxx
 #	   (see also separate file README)
 #
 # License: GPL (see file LICENSE)
@@ -39,7 +40,7 @@ tarcmd=gtar
 if [[ `tar --version 2>&1` = *GNU* ]]; then
   tarcmd=tar
 fi
-filecmd='file -L';
+filecmd='file -L -s';
 sep=:						# file name separator
 altsep==					# alternate separator character
 if [[ -f "$1" && "$1" = *$sep* || "$1" = *$altsep ]]; then
@@ -140,6 +141,8 @@ get_cmd () {
       cmd="iszip $2 $file2"
     elif [[ "$1" = *\ ar\ archive* ]]; then
       cmd="isar $2 $file2"
+    elif [[ "$1" = *x86\ boot\ sector* ]]; then
+      cmd="isfloppy $2 $file2"
     fi
   fi
 }
@@ -184,6 +187,26 @@ isrpm () {
   cat $tmp.1
 }
 
+
+isfloppy () {
+# get the device to drive mapping
+  mtoolstest |
+  while read i1 i2
+  do
+    if [[ "$i1" = *$1* ]]; then
+      if [[ "$2" = "" ]]; then
+	mdir $drive
+      else
+	mtype $drive$2
+      fi
+      return
+    elif [[ "$i1" = drive ]]; then
+      drive=$i2
+    fi
+  done
+}
+
+
 isfinal() {
 
   if [[ "$3" = $sep || "$3" = $sep$sep ]]; then
@@ -214,6 +237,10 @@ isfinal() {
   elif [[ "$1" = *Debian* ]]; then
     echo "==> use Deb_file${sep}contained_file to view a file in the Deb"
     dpkg -c ${2#-}
+  elif [[ "$1" = *text\ executable* ]]; then
+    if [[ "$2" = - ]]; then
+      cat
+    fi
   elif [[ "$1" = *executable* ]]; then
     echo "==> append $sep to filename to view the binary file"
     strings ${2#-}
@@ -226,6 +253,9 @@ isfinal() {
   elif [[ "$1" = *Zip* ]]; then
     echo "==> use zip_file${sep}contained_file to view a file in the archive"
     unzip -lv "$2"
+  elif [[ "$1" = *x86\ boot\ sector* ]]; then
+    echo "==> use $2${sep}contained_file to view a file on the floppy"
+    isfloppy $2
   elif [[ "$1" = *HTML* ]]; then
 #   browser="w3m -X -T text/html"
     browser=lynx
